Overview - WeeWX 5.0
Author: Tom Keffer <tkeffer@gmail.com>

Skip to content

# Troubleshooting

These are some common problems users encounter when installing and running WeeWX.

Hardware Problems
Software Problems
Meteorological Problems

If you have problems, here are a few things to try:

1. Look at the log file. We are always happy to take questions, but the first thing someone will ask is, "What did you find in the log file?"

2. Run `weewxd` directly, rather than as a daemon. Generally, WeeWX will catch and log any unrecoverable exceptions, but if you are getting strange results, it is worth running directly and looking for any clues.

3. Set the option `debug = 1` in `weewx.conf`. This will put much more information in the log file, which can be very useful for troubleshooting and debugging!

4. If you are still stuck, post your problem to the weewx-user group. The Wiki has some guidelines on how to do an effective post.